@@ -10,7 +10,8 @@ while (<DATA>) {
   chomp;
   my $r = $gi->record_by_name($_);
   if ($r) {
-    print join("\t",$r->country_code,$r->country_name,$r->city,$r->region,$r->postal_code,$r->latitude,$r->longitude) . "\n";
+    print join("\t",$r->country_code,$r->country_name,$r->city,$r->region,$r->postal_code,$r->latitude,$r->longitude,
+	$r->dma_code,$r->area_code) . "\n";
   } else {
     print "UNDEF\n";
   }
@@ -23,3 +24,4 @@ __DATA__
 yahoo.com
 amazon.com
 4.2.144.64
+24.24.24.24
